<?php
namespace Ak\View\Renderer;

use Ak\ServiceManager\AbstractFactory\PluginManagerAbstractFactory;
use Ak\View\HelperPluginManager;
use Interop\Container\ContainerInterface;
use Laminas\ServiceManager\Factory\FactoryInterface;
use Laminas\View\Renderer\PhpRenderer;
use Laminas\View\Renderer\RendererInterface;
use Laminas\View\Resolver\TemplatePathStack;

/**
 * Stvara novu instancu PhpRenderera.
 *
 * @package Ak\View\Renderer
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/view
 */
final class PhpRendererFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return RendererInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config')['view'] ?? [];

        $pluginManagerFactory = new PluginManagerAbstractFactory();
        $pluginManager = $pluginManagerFactory($container, HelperPluginManager::class);

        $renderer = new PhpRenderer();
        $renderer->setHelperPluginManager($pluginManager);

        $resolver = new TemplatePathStack([
            'script_paths' => $config['script_paths'] ?? [],
        ]);
        $renderer->setResolver($resolver);

        return $renderer;
    }
}
