<?php
namespace AkTest\View\Helper;

use Ak\View\Helper\AssetUrl;
use AkTest\View\AbstractTestCase;
use Laminas\View\Helper\BasePath;

final class AssetUrlHelperTest extends AbstractTestCase
{
    public function testIsRegistered()
    {
        $manager = $this->getHelperManager();

        $this->assertContainerHasService($manager, [
            'asset_url',
            'assetUrl',
            'asseturl',
            AssetUrl::class,
        ], AssetUrl::class, true);
    }

    public function testWillCreateAFullyQualifiedUrl()
    {
        $manager = $this->getHelperManager();
        /** @var BasePath $basePath */
        $basePath = $manager->get(BasePath::class);
        $basePath->setBasePath('/');

        $helper = $manager->get('asset_url');
        $resolved = $helper('asset.js');

        $this->assertRegExp('/^https?:/', $resolved);
    }

    public function testCanUseAnyBasePathHelper()
    {
        $helper = $this->getHelper('asset_url', [
            'view_helpers' => [
                'aliases' => [
                    'base_path' => 'basePath',
                    BasePath::class => 'basePath',
                ],
            ],
        ]);

        $helper('asset.js');
        $this->addToAssertionCount(1);
    }
}
